# APIKeyIntrospectAuthorizationInfo

The information provided by a request using APIKey based authorization.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**key** | **str** | The APIKey used to authorize the request. | 
**username** | **str** | The username portion of the APIKey authorization. Typically an email address.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


